@@ -70,7 +70,8 @@ class MetOfficeDataHub(BaseMetOfficeDataHub):
                 file_id = file.fileId
 
                 variable = file.fileId
-                datetime = variable.split("_")[-2]
+                datetime = variable.split("_")[-1]
+                logger.debug(f'Date time of file is {datetime}')
 
                 # There seem to be two files that are the same,
                 # one with '+HH' and one with 'YYYYMMDDHH'
@@ -84,8 +85,10 @@ class MetOfficeDataHub(BaseMetOfficeDataHub):
                     # put local file in file object
                     file.local_filename = filename
                     self.files.append(file)
+                else:
+                    logger.debug(f'Not adding {file_id} to list')
 
-        logger.info("All files downloaded")
+        logger.info(f"All files downloaded ({len(self.files)}")
 
     def load_file(self, file) -> xr.Dataset:
         """Load one grib file"""
